# Status200OkNoContent

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**data** | [**list[Status200OkNoContentData]**](Status200OkNoContentData.md) |  | [optional] 
**type** | **str** |  | [optional] [default to 'no_content']
**size** | **int** |  | [optional] [default to 1]
**status** | **int** |  | [optional] [default to 200]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

